@@ -23,7 +23,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 ********************************************************************PGR-GNU*/
 
-#include "../../common/src/pgr_types.h"
 #include "postgres.h"
 #include "executor/spi.h"
 #include "funcapi.h"
@@ -36,56 +35,23 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <stdlib.h>
 #include <search.h>
 
+#include "../../common/src/pgr_types.h"
 #include "../../common/src/postgres_connection.h"
-#include "bdastar.h"
-
-//-------------------------------------------------------------------------
-
-/*
- * Define this to have profiling enabled
- */
-//#define PROFILE
-
-#ifdef PROFILE
-#include <sys/time.h>
-
-struct timeval prof_astar, prof_store, prof_extract, prof_total;
-long proftime[5];
-long profipts1, profipts2, profopts;
-
-#define profstart(x) do { gettimeofday(&x, NULL); } while (0);
-#define profstop(n, x) do { struct timeval _profstop;   \
-        long _proftime;                         \
-        gettimeofday(&_profstop, NULL);                         \
-        _proftime = ( _profstop.tv_sec*1000000+_profstop.tv_usec) -     \
-                ( x.tv_sec*1000000+x.tv_usec); \
-        elog(NOTICE, \
-                "PRF(%s) %lu (%f ms)", \
-                (n), \
-             _proftime, _proftime / 1000.0);    \
-        } while (0);
-
-#else
-
-#define profstart(x) do { } while (0);
-#define profstop(n, x) do { } while (0);
-
-#endif // PROFILE
+#include "./bdastar_driver.h"
 
 
 //-------------------------------------------------------------------------
 
+PGDLLEXPORT
 Datum bidir_astar_shortest_path(PG_FUNCTION_ARGS);
 
 #undef DEBUG
 #include "../../common/src/debug_macro.h"
 
-
 // The number of tuples to fetch from the SPI cursor at each iteration
 #define TUPLIMIT 1000
 
-typedef struct edge_astar_columns
-{
+typedef struct edge_astar_columns {
   int id;
   int source;
   int target;
@@ -101,8 +67,7 @@ typedef struct edge_astar_columns
 static int
 fetch_edge_astar_columns(SPITupleTable *tuptable,
              edge_astar_columns_t *edge_columns,
-             bool has_reverse_cost)
-{
+             bool has_reverse_cost) {
   edge_columns->id = SPI_fnumber(SPI_tuptable->tupdesc, "id");
   edge_columns->source = SPI_fnumber(SPI_tuptable->tupdesc, "source");
   edge_columns->target = SPI_fnumber(SPI_tuptable->tupdesc, "target");
@@ -112,7 +77,6 @@ fetch_edge_astar_columns(SPITupleTable *tuptable,
       edge_columns->source == SPI_ERROR_NOATTRIBUTE ||
       edge_columns->target == SPI_ERROR_NOATTRIBUTE ||
       edge_columns->cost == SPI_ERROR_NOATTRIBUTE) {
-
       elog(ERROR, "Error, query must return columns "
             "'id', 'source', 'target' and 'cost'");
       return -1;
@@ -123,7 +87,6 @@ fetch_edge_astar_columns(SPITupleTable *tuptable,
       SPI_gettypeid(SPI_tuptable->tupdesc,
             edge_columns->target) != INT4OID ||
       SPI_gettypeid(SPI_tuptable->tupdesc, edge_columns->cost) != FLOAT8OID) {
-
       elog(ERROR, "Error, columns 'source', 'target' must be of type int4, "
             "'cost' must be of type float8");
       return -1;
@@ -161,7 +124,6 @@ fetch_edge_astar_columns(SPITupleTable *tuptable,
       edge_columns->s_y == SPI_ERROR_NOATTRIBUTE ||
       edge_columns->t_x == SPI_ERROR_NOATTRIBUTE ||
       edge_columns->t_y == SPI_ERROR_NOATTRIBUTE) {
-
       elog(ERROR, "Error, query must return columns "
        "'x1', 'x2', 'y1' and 'y2'");
       return -1;
@@ -169,7 +131,7 @@ fetch_edge_astar_columns(SPITupleTable *tuptable,
 
   PGR_DBG("columns: x1 %i y1 %i x2 %i y2 %i",
       edge_columns->s_x, edge_columns->s_y,
-      edge_columns->t_x,edge_columns->t_y);
+      edge_columns->t_x, edge_columns->t_y);
 
   return 0;
 }
@@ -177,8 +139,7 @@ fetch_edge_astar_columns(SPITupleTable *tuptable,
 static void
 fetch_edge_astar(HeapTuple *tuple, TupleDesc *tupdesc,
          edge_astar_columns_t *edge_columns,
-         edge_astar_t *target_edge)
-{
+         edge_astar_t *target_edge) {
   Datum binval;
   bool isnull;
 
@@ -227,8 +188,7 @@ fetch_edge_astar(HeapTuple *tuple, TupleDesc *tupdesc,
 static int compute_shortest_path_astar(char* sql, int source_vertex_id,
                        int target_vertex_id, bool directed,
                        bool has_reverse_cost,
-                       path_element_t **path, size_t *path_count)
-{
+                       path_element_t **path, size_t *path_count) {
   void *SPIplan;
   Portal SPIportal;
   bool moredata = TRUE;
@@ -236,18 +196,22 @@ static int compute_shortest_path_astar(char* sql, int source_vertex_id,
   edge_astar_t *edges = NULL;
   size_t total_tuples = 0;
 
-  int v_max_id=0;
-  int v_min_id=INT_MAX;
+  int v_max_id = 0;
+  int v_min_id = INT_MAX;
 
-  edge_astar_columns_t edge_columns = {.id= -1, .source= -1, .target= -1,
-                       .cost= -1, .reverse_cost= -1,
-                       .s_x= -1, .s_y= -1, .t_x= -1, .t_y= -1};
+#ifndef _MSC_VER
+  edge_astar_columns_t edge_columns = {.id =  -1, .source =  -1, .target =  -1,
+                       .cost =  -1, .reverse_cost =  -1,
+                       .s_x =  -1, .s_y =  -1, .t_x =  -1, .t_y =  -1};
+#else  // _MSC_VER
+  edge_astar_columns_t edge_columns = {-1, -1, -1, -1, -1, -1, -1, -1, -1};
+#endif  // _MSC_VER
   char *err_msg;
   int ret = -1;
   register int z;
 
-  int s_count=0;
-  int t_count=0;
+  int s_count = 0;
+  int t_count = 0;
 
   struct vItem {
     int id;
@@ -295,60 +259,55 @@ static int compute_shortest_path_astar(char* sql, int source_vertex_id,
                        &edges[total_tuples - ntuples + t]);
           }
           SPI_freetuptable(tuptable);
-      }
-      else {
+      } else {
           moredata = FALSE;
       }
   }
 
-  //defining min and max vertex id
+  // defining min and max vertex id
 
-  PGR_DBG("Total %i tuples", total_tuples);
+  PGR_DBG("Total %lu tuples", total_tuples);
 
-  for(z=0; z<total_tuples; z++)
-  {
-    if(edges[z].source<v_min_id) v_min_id=edges[z].source;
-    if(edges[z].source>v_max_id) v_max_id=edges[z].source;
-    if(edges[z].target<v_min_id) v_min_id=edges[z].target;
-    if(edges[z].target>v_max_id) v_max_id=edges[z].target;
+  for (z = 0; z < total_tuples; z++) {
+    if (edges[z].source < v_min_id) v_min_id = edges[z].source;
+    if (edges[z].source > v_max_id) v_max_id = edges[z].source;
+    if (edges[z].target < v_min_id) v_min_id = edges[z].target;
+    if (edges[z].target > v_max_id) v_max_id = edges[z].target;
     PGR_DBG("%i <-> %i", v_min_id, v_max_id);
   }
 
   //::::::::::::::::::::::::::::::::::::
   //:: reducing vertex id (renumbering)
   //::::::::::::::::::::::::::::::::::::
-  for(z=0; z<total_tuples; z++) {
-    //check if edges[] contains source and target
-    if(edges[z].source == source_vertex_id ||
+  for (z=0; z < total_tuples; z++) {
+    // check if edges[] contains source and target
+    if (edges[z].source == source_vertex_id ||
        edges[z].target == source_vertex_id)
       ++s_count;
-    if(edges[z].source == target_vertex_id ||
+    if (edges[z].source == target_vertex_id ||
        edges[z].target == target_vertex_id)
       ++t_count;
 
-    edges[z].source-=v_min_id;
-    edges[z].target-=v_min_id;
+    edges[z].source -= v_min_id;
+    edges[z].target -= v_min_id;
     PGR_DBG("%i - %i", edges[z].source, edges[z].target);
   }
 
-  PGR_DBG("Total %i tuples", total_tuples);
+  PGR_DBG("Total %lu tuples", total_tuples);
 
-  if(s_count == 0) {
+  if (s_count == 0) {
     elog(ERROR, "Start vertex was not found.");
     return -1;
   }
 
-  if(t_count == 0) {
+  if (t_count == 0) {
     elog(ERROR, "Target vertex was not found.");
     return -1;
   }
 
-  PGR_DBG("Total %i tuples", total_tuples);
+  PGR_DBG("Total %lu tuples", total_tuples);
 
-  profstop("extract", prof_extract);
-  profstart(prof_astar);
-
-  PGR_DBG("Calling bidir_astar <%i>\n", total_tuples);
+  PGR_DBG("Calling bidir_astar <%lu>\n", total_tuples);
 
   // calling C++ A* function
   ret = bdastar_wrapper(edges, total_tuples, v_max_id + 1, source_vertex_id-v_min_id,
@@ -356,21 +315,17 @@ static int compute_shortest_path_astar(char* sql, int source_vertex_id,
             directed, has_reverse_cost,
             path, path_count, &err_msg);
 
-  PGR_DBG("SIZE %i\n",*path_count);
+  PGR_DBG("SIZE %lu\n", *path_count);
 
-  PGR_DBG("ret =  %i\n",ret);
+  PGR_DBG("ret =  %i\n", ret);
 
   //::::::::::::::::::::::::::::::::
   //:: restoring original vertex id
   //::::::::::::::::::::::::::::::::
-  for(z=0; z<*path_count; z++) {
-    //PGR_DBG("vetex %i\n",(*path)[z].vertex_id);
-    (*path)[z].vertex_id+=v_min_id;
+  for (z = 0; z < *path_count; z++) {
+    // PGR_DBG("vetex %i\n",(*path)[z].vertex_id);
+    (*path)[z].vertex_id += v_min_id;
   }
-
-  profstop("astar", prof_astar);
-  profstart(prof_store);
-
   if (ret < 0) {
       elog(ERROR, "Error computing path: %s", err_msg);
   }
@@ -380,9 +335,8 @@ static int compute_shortest_path_astar(char* sql, int source_vertex_id,
 
 
 PG_FUNCTION_INFO_V1(bidir_astar_shortest_path);
-Datum
-bidir_astar_shortest_path(PG_FUNCTION_ARGS)
-{
+PGDLLEXPORT Datum
+bidir_astar_shortest_path(PG_FUNCTION_ARGS) {
   FuncCallContext     *funcctx;
   uint32_t                  call_cntr;
   uint32_t                  max_calls;
@@ -397,10 +351,6 @@ bidir_astar_shortest_path(PG_FUNCTION_ARGS)
       int ret;
 #endif
 
-      // XXX profiling messages are not thread safe
-      profstart(prof_total);
-      profstart(prof_extract);
-
       /* create a function context for cross-call persistence */
       funcctx = SRF_FIRSTCALL_INIT();
 
@@ -435,7 +385,7 @@ bidir_astar_shortest_path(PG_FUNCTION_ARGS)
       funcctx->max_calls = (uint32_t)path_count;
       funcctx->user_fctx = path;
 
-      PGR_DBG("Path count %i", path_count);
+      PGR_DBG("Path count %lu", path_count);
 
       funcctx->tuple_desc =
             BlessTupleDesc(RelationNameGetTupleDesc("pgr_costResult"));
@@ -490,16 +440,9 @@ bidir_astar_shortest_path(PG_FUNCTION_ARGS)
       pfree(nulls);
 
       SRF_RETURN_NEXT(funcctx, result);
-  }
-  else {   /* do when there is no more left */
+  } else {   /* do when there is no more left */
       PGR_DBG("Freeing path");
       if (path) free(path);
-
-      profstop("store", prof_store);
-      profstop("total", prof_total);
-#ifdef PROFILE
-      elog(NOTICE, "_________");
-#endif
       SRF_RETURN_DONE(funcctx);
   }
 }
