@@ -1,5 +1,5 @@
 -- -------------------------------------------------------------------
--- pgrouting_utilities.sql
+-- pgrouting_version.sql
 -- AuthorL Stephen Woodbridge <woodbri@imaptools.com>
 -- Copyright 2013 Stephen Woodbridge
 -- This file is release unde an MIT-X license.
@@ -9,7 +9,7 @@ CREATE OR REPLACE FUNCTION pgr_version()
 RETURNS TABLE(
 		"version" varchar, 
 		tag varchar,
-		build varchar,
+		--build varchar,
 		hash varchar,
 		branch varchar,
 		boost varchar
@@ -28,7 +28,7 @@ DECLARE
 BEGIN
     RETURN QUERY SELECT '${PGROUTING_VERSION_STRING}'::varchar AS version, 
     					'${PGROUTING_GIT_TAG}'::varchar AS tag, 
-                        '${PGROUTING_GIT_BUILD}'::varchar AS build, 
+                        --'${PGROUTING_GIT_BUILD}'::varchar AS build, 
                         '${PGROUTING_GIT_HASH}'::varchar AS hash, 
                         '${PGROUTING_GIT_BRANCH}'::varchar AS branch, 
                         '${Boost_MAJOR_VERSION}.${Boost_MINOR_VERSION}.${Boost_SUBMINOR_VERSION}'::varchar AS boost;
