@@ -25,6 +25,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #ifndef SRC_DRIVING_DISTANCE_SRC_BOOST_INTERFACE_DRIVEDIST_H_
 #define SRC_DRIVING_DISTANCE_SRC_BOOST_INTERFACE_DRIVEDIST_H_
 
+#include "stdlib.h"
 #include "./../../common/src/pgr_types.h"
 
 #ifdef __cplusplus
@@ -34,7 +35,7 @@ extern "C" {
     void do_pgr_driving_many_to_dist(
             pgr_edge_t  * edges, size_t total_tuples,
             int64_t  *start_vertex, size_t s_len,
-            float8 distance,
+            double distance,
             bool directed,
             bool equicost,
             General_path_element_t **ret_path, size_t *path_count,
