@@ -1,16 +1,20 @@
+/*
+ * THIS CODE IS DEPRECATED
+ */
+
 /*PGR-MIT*****************************************************************
 
-*  $Id: tsplib.c,v 1.1 2006/05/13 23:39:56 woodbri Exp $
+*  $Id: tsplib.c, v 1.1 2006/05/13 23:39:56 woodbri Exp $
 *
 *  tsplib
-*  Copyright 2005,2013, Stephen Woodbridge, All rights Reserved
+*  Copyright 2005, 2013, Stephen Woodbridge, All rights Reserved
 *  This file is released under MIT-X license as part of pgRouting.
 
 ------
 MIT/X license
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
-of this software and associated documentation files (the "Software"), to deal
+of this software and associated documentation files(the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
@@ -39,7 +43,7 @@ THE SOFTWARE.
 *  Routine to calculate the node order for a Traveling Salesman Problem
 *  from a distance matrix.
 *
-*  $Log: tsplib.c,v $
+*  $Log: tsplib.c, v $
 *  Revision 1.1  2006/05/13 23:39:56  woodbri
 *  Initial checkin of IMT::TSP module.
 *
@@ -47,17 +51,17 @@ THE SOFTWARE.
 *
 **********************************************************************
 *
-* Simulated annealing and a non symetric
+* Simulated annealing and a non symmetric
 * Euclidian Traveling Salesman Problem.
 *
 * Solution based on local search heuristics for
-* non-crossing paths and nearest neighbors 
+* non-crossing paths and nearest neighbors
 *
 * Storage Requirements: 4n ints
 *
-* Problem: given an nXn matrix of costs for n cities in the plane, 
-* find a permutation pi_1, pi_2, ..., pi_n of 1, 2, ..., n that 
-* minimizes sum for 1<=i<n D(pi_i,pi_i+1), where D(i,j) is the 
+* Problem: given an nXn matrix of costs for n cities in the plane,
+* find a permutation pi_1, pi_2, ..., pi_n of 1, 2, ..., n that
+* minimizes sum for 1<=i<n D(pi_i, pi_i+1), where D(i, j) is the
 * euclidian distance between cities i and j from the matrix
 *
 * This means that the ith row is the "from" city and the jth column
@@ -66,45 +70,44 @@ THE SOFTWARE.
 * NOTE: costs are assumed to be ints, so scaling them to meters or
 * some other int would be advisable.
 *
-* NOTE: the internal cost calculations ASSUME a symetric matrix. There
-* are notes of what needs to be updated, but all D(i,j)s need to be
+* NOTE: the internal cost calculations ASSUME a symmetric matrix. There
+* are notes of what needs to be updated, but all D(i, j)s need to be
 * reviewed because order is important for asymetric cases.
 *
-* Note: with n cities, there is (n-1)!/2 possible tours.
+* Note: with n cities, there is(n-1)!/2 possible tours.
 * factorial(10)=3628800  factorial(50)=3E+64  factorial(150)=5.7E+262
 * If we could check one tour per clock cycle on a 100 MHZ computer, we
 * would still need to wait approximately 10^236 times the age of the
-* universe to explore all tours for 150 cities. 
+* universe to explore all tours for 150 cities.
 *
-* Derivied from code 1995 by Maugis Lionel (Sofreavia) on sid1
+* Derivied from code 1995 by Maugis Lionel(Sofreavia) on sid1
 * that was placed in the public domain.
 *************************************************************************/
 
-//#ifdef __MINGW64__
-//#define ELOG_H
-//#include <winsock2.h>
-//#endif
+// #ifdef __MINGW64__
+// #define ELOG_H
+// #include <winsock2.h>
+// #endif
 #include <postgres.h>
 #include <string.h>    /* memcpy */
 #include <math.h>      /* exp    */
 
-#include "tsp.h"
+#include "./tsp.h"
 
 #undef DEBUG
-//#define DEBUG 1
+// #define DEBUG 1
 #include "../../common/src/debug_macro.h"
 
 
-
 #define T_INIT                        100
 #define FINAL_T                       0.1
-#define COOLING                       0.9 /* to lower down T (< 1) */
-#define TRIES_PER_T                   500*n  
-#define IMPROVED_PATH_PER_T           60*n   
+#define COOLING                       0.9 /* to lower down T(< 1) */
+#define TRIES_PER_T                   500*n
+#define IMPROVED_PATH_PER_T           60*n
 
 /*
  *   MACHINE INDEPENDENT RANDOM NUMBER GENERATOR
- *   Written by:  DIMACS  (modified for TSP)
+ *   Written by:  DIMACS (modified for TSP)
 */
 
 #define PRANDMAX 1000000000
@@ -116,8 +119,7 @@ static
 int Rand(void);
 
 static
-void initRand (int seed)
-{
+void initRand(int seed) {
     int i, ii;
     int last, next;
 
@@ -127,7 +129,7 @@ void initRand (int seed)
     arr[0] = last = seed;
     next = 1;
     for (i = 1; i < 55; i++) {
-        ii = (21 * i) % 55;
+        ii =(21 * i) % 55;
         arr[ii] = next;
         next = last - next;
         if (next < 0)
@@ -137,12 +139,11 @@ void initRand (int seed)
     a = 0;
     b = 24;
     for (i = 0; i < 165; i++)
-        last = Rand ();
+        last = Rand();
 }
 
 static
-int Rand (void)
-{
+int Rand(void) {
     int t;
 
     if (a-- == 0)
@@ -178,25 +179,24 @@ typedef struct tspstruct {
     DTYPE bestlen;
     int *iorder;
     int *jorder;
-    int *border;  // best order we find
+    int *border;  //  best order we find
     float b[4];
 } TSP;
 
-#define MOD(i,n)    ((i) % (n) >= 0 ? (i) % (n) : (i) % (n) + (n))
-#define D(x,y) dist[(x)*n+y]        
+#define MOD(i, n)   ((i) %(n) >= 0 ?(i) %(n) :(i) %(n) +(n))
+#define D(x, y) dist[(x)*n+y]
 
-#define MIN(a,b) ((a)<(b)?(a):(b))
-#define MAX(a,b) ((a)>(b)?(a):(b))
-#define sqr(x)   ((x)*(x))
+#define MIN(a, b)((a) < (b)?(a) : (b))
+#define MAX(a, b)((a) > (b)?(a) : (b))
+#define sqr(x)  ((x)*(x))
 
 /*
  * Prim's approximated TSP tour
  * See also [Cristophides'92]
  */
 static
-int findEulerianPath(TSP *tsp)
-{
-    int *mst, *arc;    
+int findEulerianPath(TSP *tsp) {
+    int *mst, *arc;
     int i, j, k, l, a;
     int n, *iorder, *jorder;
     DTYPE d;
@@ -210,54 +210,47 @@ int findEulerianPath(TSP *tsp)
     maxd   = tsp->maxd;
     n      = tsp->n;
 
-    if (!(mst = (int*) palloc((size_t) n * sizeof(int))) ||
-        !(arc = (int*) palloc((size_t) n * sizeof(int))) ||
-        !(dis = (DTYPE*) palloc((size_t) n * sizeof(DTYPE))) )
-    {
+    if (!(mst =(int*) palloc((size_t) n * sizeof(int))) ||
+        !(arc =(int*) palloc((size_t) n * sizeof(int))) ||
+        !(dis =(DTYPE*) palloc((size_t) n * sizeof(DTYPE))) ) {
         elog(ERROR, "Failed to allocate memory!");
         return -1;
     }
-    //PGR_DBG("findEulerianPath: 1");
+    // PGR_DBG("findEulerianPath: 1");
 
     k = -1;
     j = -1;
     d = maxd;
     dis[0] = -1;
-    for (i = 1; i < n; i++)
-    {
-        dis[i] = D(i,0);
+    for (i = 1; i < n; i++) {
+        dis[i] = D(i, 0);
         arc[i] = 0;
-        if (d > dis[i])
-        {
+        if (d > dis[i]) {
             d = dis[i];
             j = i;
         }
     }
-    //PGR_DBG("findEulerianPath: j=%d", j);
+    // PGR_DBG("findEulerianPath: j=%d", j);
 
     if (j == -1)
         elog(ERROR, "Error TSP fail to findEulerianPath, check your distance matrix is valid.");
 
     /*
-     * O(n^2) Minimum Spanning Trees by Prim and Jarnick 
-     * for graphs with adjacency matrix. 
+     * O(n^2) Minimum Spanning Trees by Prim and Jarnick
+     * for graphs with adjacency matrix.
      */
-    for (a = 0; a < n - 1; a++)
-    {
+    for (a = 0; a < n - 1; a++) {
         mst[a] = j * n + arc[j]; /* join fragment j with MST */
-        dis[j] = -1; 
+        dis[j] = -1;
         d = maxd;
-        for (i = 0; i < n; i++)
-        {
-            if (dis[i] >= 0) /* not connected yet */
-            {
-                if (dis[i] > D(i,j))
-                {
-                    dis[i] = D(i,j);
+        for (i = 0; i < n; i++) {
+            if (dis[i] >= 0) {
+                /* not connected yet */
+                if (dis[i] > D(i, j)) {
+                    dis[i] = D(i, j);
                     arc[i] = j;
                 }
-                if (d > dis[i])
-                {
+                if (d > dis[i]) {
                     d = dis[i];
                     k = i;
                 }
@@ -265,7 +258,7 @@ int findEulerianPath(TSP *tsp)
         }
         j = k;
     }
-    //PGR_DBG("findEulerianPath: 3");
+    // PGR_DBG("findEulerianPath: 3");
 
     /*
      * Preorder Tour of MST
@@ -273,101 +266,94 @@ int findEulerianPath(TSP *tsp)
 #define VISITED(x) jorder[x]
 #define NQ(x) arc[l++] = x
 #define DQ()  arc[--l]
-#define EMPTY (l==0)
-        
+#define EMPTY (l == 0)
+
     for (i = 0; i < n; i++) VISITED(i) = 0;
     k = 0; l = 0; d = 0; NQ(0);
-    while (!EMPTY)
-    {
+    while (!EMPTY) {
         i = DQ();
-        if (!VISITED(i))
-        {
+        if (!VISITED(i)) {
             iorder[k++] = i;
-            VISITED(i)  = 1;            
-            for (j = 0; j < n - 1; j++) /* push all kids of i */
-            {
-                if (i == mst[j]%n) NQ(mst[j]/n); 
-            }    
+            VISITED(i)  = 1;
+            for (j = 0; j < n - 1; j++) /* push all kids of i */ {
+                if (i == mst[j]%n) NQ(mst[j]/n);
+            }
         }
     }
-    //PGR_DBG("findEulerianPath: 4");
+    // PGR_DBG("findEulerianPath: 4");
 
     return 0;
 }
 
 static
-DTYPE pathLength (TSP *tsp)
-{
+DTYPE pathLength(TSP *tsp) {
     unsigned int i;
     DTYPE len = 0;
 
     int *iorder = tsp->iorder;
     DTYPE *dist   = tsp->dist;
-    int  n      = tsp->n;
-    
-    for (i = 0; i < n-1; i++)
-    {
+    int  n = tsp->n;
+
+    for (i = 0; i < n-1; i++) {
         len += D(iorder[i], iorder[i+1]);
     }
     len += D(iorder[n-1], iorder[0]); /* close path */
-    return (len);
+    return(len);
 }
 
 /*
  * Local Search Heuristics
  *  b-------a        b       a
  *  .       .   =>   .\     /.
- *  . d...e .        . e...d .  
+ *  . d...e .        . e...d .
  *  ./     \.        .       .
  *  c       f        c-------f
  */
 static
-DTYPE getThreeWayCost (TSP *tsp, Path p)
-{
+DTYPE getThreeWayCost(TSP *tsp, Path p) {
     int a, b, c, d, e, f;
     int *iorder = tsp->iorder;
     DTYPE *dist   = tsp->dist;
     int n       = tsp->n;
 
-    a = iorder[MOD(p[0]-1,n)];
+    a = iorder[MOD(p[0]-1, n)];
     b = iorder[p[0]];
     c = iorder[p[1]];
-    d = iorder[MOD(p[1]+1,n)];
+    d = iorder[MOD(p[1]+1, n)];
     e = iorder[p[2]];
-    f = iorder[MOD(p[2]+1,n)];
+    f = iorder[MOD(p[2]+1, n)];
 
-    return (D(a,d) + D(e,b) + D(c,f) - D(a,b) - D(c,d) - D(e,f)); 
-        /* add cost between d and e if non symetric TSP */ 
+    return(D(a, d) + D(e, b) + D(c, f) - D(a, b) - D(c, d) - D(e, f));
+        /* add cost between d and e if non symmetric TSP */
 }
 
 static
-void doThreeWay (TSP *tsp, Path p)
-{
+void doThreeWay(TSP *tsp, Path p) {
     int i, count, m1, m2, m3, a, b, c, d, e, f;
     int *iorder = tsp->iorder;
     int *jorder = tsp->jorder;
     int n       = tsp->n;
-    
-    a = MOD(p[0]-1,n);
+
+    a = MOD(p[0]-1, n);
     b = p[0];
     c = p[1];
-    d = MOD(p[1]+1,n);
+    d = MOD(p[1]+1, n);
     e = p[2];
-    f = MOD(p[2]+1,n);    
-    
-    m1 = MOD(n+c-b,n)+1;  /* num cities from b to c */
-    m2 = MOD(n+a-f,n)+1;  /* num cities from f to a */
-    m3 = MOD(n+e-d,n)+1;  /* num cities from d to e */
+    f = MOD(p[2]+1, n);
+
+    m1 = MOD(n+c-b, n)+1;  /* num cities from b to c */
+    m2 = MOD(n+a-f, n)+1;  /* num cities from f to a */
+    m3 = MOD(n+e-d, n)+1;  /* num cities from d to e */
 
     count = 0;
     /* [b..c] */
-    for (i = 0; i < m1; i++) jorder[count++] = iorder[MOD(i+b,n)];
+    for (i = 0; i < m1; i++) jorder[count++] = iorder[MOD(i+b, n)];
 
     /* [f..a] */
-    for (i = 0; i < m2; i++) jorder[count++] = iorder[MOD(i+f,n)];
+    for (i = 0; i < m2; i++) jorder[count++] = iorder[MOD(i+f, n)];
 
     /* [d..e] */
-    for (i = 0; i < m3; i++) jorder[count++] = iorder[MOD(i+d,n)];
+    for (i = 0; i < m3; i++) jorder[count++] = iorder[MOD(i+d, n)];
 
     /* copy segment back into iorder */
     for (i = 0; i < n; i++) iorder[i] = jorder[i];
@@ -380,33 +366,29 @@ void doThreeWay (TSP *tsp, Path p)
  *   a  d       a  d
  */
 static
-DTYPE getReverseCost (TSP *tsp, Path p)
-{
+DTYPE getReverseCost(TSP *tsp, Path p) {
     int a, b, c, d;
     int *iorder = tsp->iorder;
     DTYPE *dist   = tsp->dist;
     int n       = tsp->n;
-    
-    a = iorder[MOD(p[0]-1,n)];
+
+    a = iorder[MOD(p[0]-1, n)];
     b = iorder[p[0]];
     c = iorder[p[1]];
-    d = iorder[MOD(p[1]+1,n)];
-    
-    return (D(d,b) + D(c,a) - D(a,b) - D(c,d));
-    /* add cost between c and b if non symetric TSP */ 
+    d = iorder[MOD(p[1]+1, n)];
+
+    return(D(d, b) + D(c, a) - D(a, b) - D(c, d));
+    /* add cost between c and b if non symmetric TSP */
 }
-static
-void doReverse(TSP *tsp, Path p)
-{
+static void doReverse(TSP *tsp, Path p) {
     int i, nswaps, first, last, tmp;
     int *iorder = tsp->iorder;
     int n       = tsp->n;
-    
+
 
     /* reverse path b...c */
-    nswaps = (MOD(p[1]-p[0],n)+1)/2;
-    for (i = 0; i < nswaps; i++)
-    {
+    nswaps =(MOD(p[1]-p[0], n)+1)/2;
+    for (i = 0; i < nswaps; i++) {
         first = MOD(p[0]+i, n);
         last  = MOD(p[1]-i, n);
         tmp   = iorder[first];
@@ -416,8 +398,7 @@ void doReverse(TSP *tsp, Path p)
 }
 
 static
-void annealing(TSP *tsp)
-{
+void annealing(TSP *tsp) {
     Path   p;
     int    i, j, pathchg;
     int    numOnPath, numNotOnPath;
@@ -425,53 +406,47 @@ void annealing(TSP *tsp)
     int    n = tsp->n;
     double energyChange, T;
 
-    pathlen = pathLength (tsp); 
+    pathlen = pathLength(tsp);
 
-    for (T = T_INIT; T > FINAL_T; T *= COOLING)  /* annealing schedule */
-    {
+    for (T = T_INIT; T > FINAL_T; T *= COOLING)  /* annealing schedule */ {
         pathchg = 0;
-        for (j = 0; j < TRIES_PER_T; j++)
-        {
+        for (j = 0; j < TRIES_PER_T; j++) {
             do {
-                p[0] = unifRand (n);
-                p[1] = unifRand (n);
+                p[0] = unifRand(n);
+                p[1] = unifRand(n);
                 /* non-empty path */
-                if (p[0] == p[1]) p[1] = MOD(p[0]+1,n);
-                numOnPath = MOD(p[1]-p[0],n) + 1;
+                if (p[0] == p[1]) p[1] = MOD(p[0]+1, n);
+                numOnPath = MOD(p[1]-p[0], n) + 1;
                 numNotOnPath = n - numOnPath;
             } while (numOnPath < 2 || numNotOnPath < 2); /* non-empty path */
-            
-            if (RANDOM() % 2) /*  threeWay */
-            {
-                do {
-                    p[2] = MOD(unifRand (numNotOnPath)+p[1]+1,n);
-                } while (p[0] == MOD(p[2]+1,n)); /* avoids a non-change */
 
-                energyChange = getThreeWayCost (tsp, p);
-                if (energyChange < 0 || RREAL < exp(-energyChange/T) )
-                {
+            if (RANDOM() % 2) /*  threeWay */ {
+                do {
+                    p[2] = MOD(unifRand(numNotOnPath)+p[1]+1, n);
+                } while (p[0] == MOD(p[2]+1, n)); /* avoids a non-change */
+
+                energyChange = getThreeWayCost(tsp, p);
+                if (energyChange < 0 || RREAL < exp(-energyChange/T)) {
                     pathchg++;
                     pathlen += energyChange;
-                    doThreeWay (tsp, p);
+                    doThreeWay(tsp, p);
                 }
-            }
-            else            /* path Reverse */
-            {
-                energyChange = getReverseCost (tsp, p);
-                if (energyChange < 0 || RREAL < exp(-energyChange/T))
-                {
+            } else {
+                /* path Reverse */
+                energyChange = getReverseCost(tsp, p);
+                if (energyChange < 0 || RREAL < exp(-energyChange/T)) {
                     pathchg++;
                     pathlen += energyChange;
-                    doReverse(tsp, p); 
+                    doReverse(tsp, p);
                 }
             }
-            // if the new length is better than best then save it as best
+            //  if the new length is better than best then save it as best
             if (pathlen < tsp->bestlen) {
                 tsp->bestlen = pathlen;
-                for (i=0; i<tsp->n; i++) tsp->border[i] = tsp->iorder[i];
+                for (i = 0; i < tsp->n; i++) tsp->border[i] = tsp->iorder[i];
             }
             if (pathchg > IMPROVED_PATH_PER_T) break; /* finish early */
-        }   
+        }
         PGR_DBG("T:%f L:%f B:%f C:%d", T, pathlen, tsp->bestlen, pathchg);
         if (pathchg == 0) break;   /* if no change then quit */
     }
@@ -479,10 +454,9 @@ void annealing(TSP *tsp)
 
 
 static
-void reverse(int num, int *ids)
-{
+void reverse(int num, int *ids) {
     int i, j, t;
-    for (i=0, j=num-1; i<j; i++, j--) {
+    for (i = 0, j = num - 1; i < j; i++, j--) {
         t = ids[j];
         ids[j] = ids[i];
         ids[i] = t;
@@ -490,8 +464,7 @@ void reverse(int num, int *ids)
 }
 
 
-int find_tsp_solution(int num, DTYPE *cost, int *ids, int start, int end, DTYPE *total_len, char *err_msg)
-{
+int find_tsp_solution(int num, DTYPE *cost, int *ids, int start, int end, DTYPE *total_len, char *err_msg) {
     int   i, j;
     int   istart = 0;
     int   jstart = 0;
@@ -499,10 +472,10 @@ int find_tsp_solution(int num, DTYPE *cost, int *ids, int start, int end, DTYPE
     int   jend = -1;
     int   rev = 0;
     TSP   tsp;
-    long  seed = -314159L;
+    int64_t  seed = -314159L;
     DTYPE blength;
 
-    PGR_DBG("sizeof(long)=%d", (int)sizeof(long));
+    PGR_DBG("sizeof(int64_t)=%d", (int)sizeof(int64_t));
 
     initRand((int) seed);
 
@@ -510,11 +483,11 @@ int find_tsp_solution(int num, DTYPE *cost, int *ids, int start, int end, DTYPE
     char bufff[2048];
     int nnn;
     PGR_DBG("---------- Matrix[%d][%d] ---------------------\n", num, num);
-    for (i=0; i<num; i++) {
+    for (i = 0; i < num; i++) {
         sprintf(bufff, "%d:", i);
         nnn = 0;
-        for (j=0; j<num; j++) {
-            nnn += sprintf(bufff+nnn, "\t%.4f", cost[i*num+j]);
+        for (j = 0; j < num; j++) {
+            nnn += sprintf(bufff + nnn, "\t%.4f", cost[i * num + j]);
         }
         PGR_DBG("%s", bufff);
     }
@@ -527,16 +500,16 @@ int find_tsp_solution(int num, DTYPE *cost, int *ids, int start, int end, DTYPE
     tsp.jorder = NULL;
     tsp.border = NULL;
 
-    if (!(tsp.iorder = (int*) palloc ((size_t) tsp.n * sizeof(int)))   ||
-        !(tsp.jorder = (int*) palloc ((size_t) tsp.n * sizeof(int)))   ||
-        !(tsp.border = (int*) palloc ((size_t) tsp.n * sizeof(int)))   ) {
+    if (!(tsp.iorder =(int*) palloc((size_t) tsp.n * sizeof(int)))   ||
+        !(tsp.jorder =(int*) palloc((size_t) tsp.n * sizeof(int)))   ||
+        !(tsp.border =(int*) palloc((size_t) tsp.n * sizeof(int)))   ) {
             elog(FATAL, "Memory allocation failed!");
             return -1;
         }
 
     tsp.dist = cost;
     tsp.maxd = 0;
-    for (i=0; i<tsp.n*tsp.n; i++) {
+    for (i=0; i < tsp.n * tsp.n; i++) {
         tsp.maxd = MAX(tsp.maxd, cost[i]);
     }
 
@@ -552,7 +525,7 @@ int find_tsp_solution(int num, DTYPE *cost, int *ids, int start, int end, DTYPE
      * Set up first eulerian path iorder to be improved by
      * simulated annealing.
      */
-    if(findEulerianPath(&tsp))
+    if (findEulerianPath(&tsp))
         return -1;
 
     blength = pathLength(&tsp);
@@ -569,26 +542,26 @@ int find_tsp_solution(int num, DTYPE *cost, int *ids, int start, int end, DTYPE
     PGR_DBG("Final Path Length: %.4f", *total_len);
 
     *total_len = tsp.bestlen;
-    for (i=0; i<tsp.n; i++) tsp.iorder[i] = tsp.border[i];
+    for (i = 0; i < tsp.n; i++) tsp.iorder[i] = tsp.border[i];
     PGR_DBG("Best Path Length: %.4f", *total_len);
 
-    // reorder ids[] with start as first
+    //  reorder ids[] with start as first
 
 #ifdef DEBUG
-    for (i=0; i<tsp.n; i++) {
+    for (i = 0; i < tsp.n; i++) {
         PGR_DBG("i: %d, ids[i]: %d, io[i]: %d, jo[i]: %d, jo[io[i]]: %d",
             i, ids[i], tsp.iorder[i], tsp.jorder[i], tsp.jorder[tsp.iorder[i]]);
     }
 #endif
 
-    // get index of start node in ids
+    //  get index of start node in ids
     for (i=0; i < tsp.n; i++) {
         if (ids[i] == start) istart = i;
         if (ids[i] == end)   iend = i;
     }
     PGR_DBG("istart: %d, iend: %d", istart, iend);
 
-    // get the idex of start in iorder
+    //  get the idex of start in iorder
     for (i=0; i < tsp.n; i++) {
         if (tsp.iorder[i] == istart) jstart = i;
         if (tsp.iorder[i] == iend)   jend = i;
@@ -600,7 +573,7 @@ int find_tsp_solution(int num, DTYPE *cost, int *ids, int start, int end, DTYPE
      * then we swap start and end and extract the list backwards
      * and later we reverse the list for the desired order.
     */
-    if ((jend > 0 && jend == jstart+1) || (jend == 0 && jstart == tsp.n-1)) {
+    if ((jend > 0 && jend == jstart+1) ||(jend == 0 && jstart == tsp.n-1)) {
         int tmp = jend;
         jend = jstart;
         jstart = tmp;
@@ -608,18 +581,18 @@ int find_tsp_solution(int num, DTYPE *cost, int *ids, int start, int end, DTYPE
         PGR_DBG("reversed start and end: jstart: %d, jend: %d", jstart, jend);
     }
 
-    // copy ids to tsp.jorder so we can rewrite ids
+    //  copy ids to tsp.jorder so we can rewrite ids
     memcpy(tsp.jorder, ids, (size_t) tsp.n * sizeof(int));
 
-    // write reordered ids into ids[]
-    // remember at this point jorder is our list if ids
-    for (i=jstart, j=0; i < tsp.n; i++, j++)
+    //  write reordered ids into ids[]
+    //  remember at this point jorder is our list if ids
+    for (i=jstart, j = 0; i < tsp.n; i++, j++)
         ids[j] = tsp.jorder[tsp.iorder[i]];
 
     for (i=0; i < jstart; i++, j++)
-        ids[j] =tsp.jorder[tsp.iorder[i]];
+        ids[j] = tsp.jorder[tsp.iorder[i]];
 
-    // if we reversed the order above, now put it correct.
+    //  if we reversed the order above, now put it correct.
     if (rev) {
         int tmp = jend;
         jend = jstart;
@@ -629,7 +602,7 @@ int find_tsp_solution(int num, DTYPE *cost, int *ids, int start, int end, DTYPE
 
 #ifdef DEBUG
     PGR_DBG("ids getting returned!");
-    for (i=0; i<tsp.n; i++) {
+    for (i=0; i < tsp.n; i++) {
         PGR_DBG("i: %d, ids[i]: %d, io[i]: %d, jo[i]: %d",
             i, ids[i], tsp.iorder[i], tsp.jorder[i]);
     }
