@@ -1,6 +1,6 @@
 #! /usr/bin/perl -w
-    eval 'exec /usr/bin/perl -S $0 ${1+"$@"}'
-        if 0; #$running_under_some_shell
+eval 'exec /usr/bin/perl -S $0 ${1+"$@"}'
+if 0; #$running_under_some_shell
 
 use strict;
 use File::Find ();
@@ -16,6 +16,7 @@ use vars qw/*name *dir *prune/;
 *prune  = *File::Find::prune;
 
 my $DOCUMENTATION = 0;
+my $INTERNAL_TESTS = 0;
 my $VERBOSE = 0;
 my $DRYRUN = 0;
 my $DEBUG = 0;
@@ -28,21 +29,22 @@ my $DBPORT;
 
 sub Usage {
     die "Usage: algorithm-tester.pl -pgver vpg -pgisver vpgis -psql /path/to/psql\n" .
-        "       -pgver vpg          - postgresql version\n" .
-        "       -pghost host        - postgresql host or socket directory to use\n" .
-        "       -pgport port        - postgresql port to use\n" .
-        "       -pguser username    - postgresql user role to use\n" .
-        "       -pgisver vpgis      - postgis version\n" .
-        "       -pgrver vpgr        - pgrouting version\n" .
-        "       -psql /path/to/psql - optional path to psql\n" .
-        "       -v                  - verbose messages for small debuging\n" .
-        "       -debug              - verbose messages for debuging(enter twice for more)\n" .
-        "       -debug1             - DEBUG1 messages (for timing reports)\n" .
-        "       -clean              - dropdb pgr_test__db__test\n" .
-        "       -ignorenotice       - ignore NOTICE statements when reporting failures\n" .
-        "       -alg 'dir'          - directory to select which algorithm subdirs to test\n" .
-        "       -documentation      - ONLY generate documentation examples\n" .
-        "       -h                  - help\n";
+    "       -pgver vpg          - postgresql version\n" .
+    "       -pghost host        - postgresql host or socket directory to use\n" .
+    "       -pgport port        - postgresql port to use\n" .
+    "       -pguser username    - postgresql user role to use\n" .
+    "       -pgisver vpgis      - postgis version\n" .
+    "       -pgrver vpgr        - pgrouting version\n" .
+    "       -psql /path/to/psql - optional path to psql\n" .
+    "       -v                  - verbose messages for small debuging\n" .
+    "       -dbg                - use when CMAKE_BUILD_TYPE = DEBUG\n" .
+    "       -debug              - verbose messages for debuging(enter twice for more)\n" .
+    "       -debug1             - DEBUG1 messages (for timing reports)\n" .
+    "       -clean              - dropdb pgr_test__db__test\n" .
+    "       -ignorenotice       - ignore NOTICE statements when reporting failures\n" .
+    "       -alg 'dir'          - directory to select which algorithm subdirs to test\n" .
+    "       -documentation      - ONLY generate documentation examples\n" .
+    "       -h                  - help\n";
 }
 
 print "RUNNING: algorithm-tester.pl " . join(" ", @ARGV) . "\n";
@@ -88,7 +90,7 @@ while (my $a = shift @ARGV) {
     elsif ($a eq '-psql') {
         $psql = shift @ARGV || Usage();
         die "'$psql' is not executable!\n"
-            unless -x $psql;
+        unless -x $psql;
     }
     elsif ($a =~ /^-h/) {
         Usage();
@@ -113,6 +115,9 @@ while (my $a = shift @ARGV) {
         $DOCUMENTATION = 1;
         $DEBUG1 = 0; # disbale timing reports during documentation generation
     }
+    elsif ($a =~ /^-dbg/i) {
+        $INTERNAL_TESTS = 1; #directory internalQueryTests is also tested
+    }
     else {
         warn "Error: unknown option '$a'\n";
         Usage();
@@ -144,18 +149,8 @@ if (length($psql)) {
         $psql = "\"$psql\"";
     }
 }
+print "Operative system found: $OS";
 
-# some unit tests
-#my $server_ver = getServerVersion();
-#my $server_ver = '9.2';
-#print "PSQL=$psql\n";
-#print "SERVER_VERSION=$server_ver\n";
-#print "version_greater_eq('9.1')=" . version_greater_eq($server_ver, '9.1') . "\n";
-#print "version_greater_eq('9.2')=" . version_greater_eq($server_ver, '9.2') . "\n";
-#print "version_greater_eq('9.3')=" . version_greater_eq($server_ver, '9.3') . "\n";
-#print "version_greater_eq('8.3')=" . version_greater_eq($server_ver, '8.3') . "\n";
-#print "template_pgrouting=" . dbExists('template_pgrouting') . "\n";
-#exit;
 
 # Traverse desired filesystems
 File::Find::find({wanted => \&want_tests}, @testpath);
@@ -224,7 +219,7 @@ sub run_test {
         createTestDB($singleDB);
         mysystem("$psql $connopts -A -t -q -f tools/testers/sampledata.sql' $singleDB >> $TMP2 2>\&1 ");
         for my $x (@{$t->{data}}) {
-           mysystem("$psql $connopts -A -t -q -f '$dir/$x' $singleDB >> $TMP2 2>\&1 ");
+            mysystem("$psql $connopts -A -t -q -f '$dir/$x' $singleDB >> $TMP2 2>\&1 ");
         }
         process_single_test($testName, $dir, $singleDB,\%res);
         mysystem("dropdb $connopts $singleDB");
@@ -232,9 +227,14 @@ sub run_test {
 
     mysystem("$psql $connopts -A -t -q -f tools/testers/sampledata.sql $DBNAME >> $TMP2 2>\&1 ");
     for my $x (@{$t->{data}}) {
-       mysystem("$psql $connopts -A -t -q -f '$dir/$x' $DBNAME >> $TMP2 2>\&1 ");
+        mysystem("$psql $connopts -A -t -q -f '$dir/$x' $DBNAME >> $TMP2 2>\&1 ");
     }
 
+    if ($INTERNAL_TESTS) {
+        for my $x (@{$t->{debugtests}}) {
+            process_single_test($x, $dir,, $DBNAME, \%res)
+        }
+    }
     if ($DOCUMENTATION) {
         for my $x (@{$t->{documentation}}) {
             process_single_test($x, $dir,, $DBNAME, \%res)
@@ -244,6 +244,19 @@ sub run_test {
         for my $x (@{$t->{tests}}) {
             process_single_test($x, $dir,, $DBNAME, \%res)
         }
+        if ($OS =~ /msys/ || $OS=~/MSW/ || $OS =~ /cygwin/) {
+            for my $x (@{$t->{windows}}) {
+                process_single_test($x, $dir,, $DBNAME, \%res)
+            }
+        } elsif ($OS=~/Mac/ ||  $OS=~/dar/) {
+            for my $x (@{$t->{macos}}) {
+                process_single_test($x, $dir,, $DBNAME, \%res)
+            }
+        } else {
+            for my $x (@{$t->{linux}}) {
+                process_single_test($x, $dir,, $DBNAME, \%res)
+            }
+        }
     }
 
     return \%res;
@@ -254,93 +267,95 @@ sub process_single_test{
     my $dir = shift;
     my $database = shift;
     my $res = shift;
-        #each tests will use clean data
+    #each tests will use clean data
 
-        print "Processing test: $dir/$x\n";
-        my $t0 = [gettimeofday];
-        #TIN = test_input_file
-        open(TIN, "$dir/$x.test.sql") || do {
-            $res->{"$dir/$x.test.sql"} = "FAILED: could not open '$dir/$x.test.sql' : $!";
+    print "Processing test: $dir/$x\n";
+    my $t0 = [gettimeofday];
+    #TIN = test_input_file
+    open(TIN, "$dir/$x.test.sql") || do {
+        $res->{"$dir/$x.test.sql"} = "FAILED: could not open '$dir/$x.test.sql' : $!";
+        $stats{z_fail}++;
+        next;
+    };
+
+    #reason of opening conection is because the set client_min_messages to warning;
+    if ($DOCUMENTATION) {
+        mysystem("mkdir -p '$dir/../doc' "); # make sure the directory exists
+        open(PSQL, "|$psql $connopts --set='VERBOSITY terse' -e $database > $dir/../doc/$x.queries 2>\&1 ") || do {
+            $res->{"$dir/$x.test.sql"} = "FAILED: could not open connection to db : $!";
             $stats{z_fail}++;
             next;
         };
-
-        #reason of opening conection is because the set client_min_messages to warning;
-        if ($DOCUMENTATION) {
-            mysystem("mkdir -p '$dir/../doc' "); # make sure the directory exists
-            open(PSQL, "|$psql $connopts --set='VERBOSITY terse' -e $database > $dir/../doc/$x.queries 2>\&1 ") || do {
-                $res->{"$dir/$x.test.sql"} = "FAILED: could not open connection to db : $!";
-                $stats{z_fail}++;
-                next;
-            };
-            print PSQL "set client_min_messages to WARNING;\n" if $ignore;
-            print PSQL "set client_min_messages to DEBUG1;\n" if $DEBUG1;
-        }
-        else {
-            open(PSQL, "|$psql $connopts --set='VERBOSITY terse' -A -t -q $database > $TMP 2>\&1 ") || do {
-                $res->{"$dir/$x.test.sql"} = "FAILED: could not open connection to db : $!";
-                $stats{z_fail}++;
-                next;
-            };
-        }
         print PSQL "set client_min_messages to WARNING;\n" if $ignore;
         print PSQL "set client_min_messages to DEBUG1;\n" if $DEBUG1;
-        my @d = ();
-        @d = <TIN>; #reads the whole file into the array @d 
-        print PSQL @d; #prints the whole fle stored in @d
-        close(PSQL); #executes everything
-        close(TIN); #closes the input file  /TIN = test input
-
-        return if $DOCUMENTATION;
-
-        my $dfile;
-        my $dfile2;
-        if ($ignore) { #decide how to compare results, if ignoring or not ignoring
-            $dfile2 = $TMP2;
-            mysystem("grep -v NOTICE '$TMP' | grep -v '^CONTEXT:' | grep -v '^PL/pgSQL function' > $dfile2");
-            $dfile = $TMP3;
-            mysystem("grep -v NOTICE '$dir/$x.result' | grep -v '^CONTEXT:' | grep -v '^PL/pgSQL function' > $dfile");
-        }
-        elsif ($DEBUG1) { #to delete CONTEXT lines
-            $dfile2 = $TMP2;
-            mysystem("grep -v '^CONTEXT:' '$TMP' | grep -v '^PL/pgSQL function' > $dfile2");
-            $dfile = $TMP3;
-            mysystem("grep -v '^CONTEXT:' '$dir/$x.result' | grep -v '^PL/pgSQL function' > $dfile");
-        }
-        else {
-            $dfile = "$dir/$x.result";
-            $dfile2 = $TMP;
-        }
-        if (! -f "$dir/$x.result") {
-            $res->{"$dir/$x.test.sql"} = "\nFAILED: result file missing : $!";
-            $stats{z_fail}++;            
+    }
+    else {
+        open(PSQL, "|$psql $connopts --set='VERBOSITY terse' -A -t -q $database > $TMP 2>\&1 ") || do {
+            $res->{"$dir/$x.test.sql"} = "FAILED: could not open connection to db : $!";
+            if (!$INTERNAL_TESTS) {
+               $stats{z_fail}++;
+            }
             next;
-        }
+        };
+    }
+    print PSQL "set client_min_messages to WARNING;\n" if $ignore;
+    print PSQL "set client_min_messages to DEBUG1;\n" if $DEBUG1;
+    my @d = ();
+    @d = <TIN>; #reads the whole file into the array @d 
+    print PSQL @d; #prints the whole fle stored in @d
+    close(PSQL); #executes everything
+    close(TIN); #closes the input file  /TIN = test input
 
-        # use diff -w to ignore white space differences like \r vs \r\n
-        #ignore white spaces when comparing
-        #dfile is expected results
-        #dfile2 is the actual results
-        my $r = `diff -w '$dfile' '$dfile2' `;
-        #looks for removing leading blanks and trailing blanks
-        $r =~ s/^\s*|\s*$//g;
-        if ($r =~ /connection to server was lost/) {
-            $res->{"$dir/$x.test.sql"} = "CRASHED SERVER: $r";
-            $stats{z_crash}++;
-            # allow the server some time to recover from the crash
-            warn "CRASHED SERVER: '$dir/$x.test.sql', sleeping 5 ...\n";
-            sleep 20;
-        }
-        #if the diff has 0 length then everything was the same, so here we detect changes
-        elsif (length($r)) {
-            $res->{"$dir/$x.test.sql"} = "FAILED: $r";
-            $stats{z_fail}++ unless $DEBUG1;
-        }
-        else {
-            $res->{"$dir/$x.test.sql"} = "Passed";
-            $stats{z_pass}++;
-        }
-        print "    test run time: " . tv_interval($t0, [gettimeofday]) . "\n";
+    return if $DOCUMENTATION;
+
+    my $dfile;
+    my $dfile2;
+    if ($ignore) { #decide how to compare results, if ignoring or not ignoring
+        $dfile2 = $TMP2;
+        mysystem("grep -v NOTICE '$TMP' | grep -v '^CONTEXT:' | grep -v '^PL/pgSQL function' > $dfile2");
+        $dfile = $TMP3;
+        mysystem("grep -v NOTICE '$dir/$x.result' | grep -v '^CONTEXT:' | grep -v '^PL/pgSQL function' > $dfile");
+    }
+    elsif ($DEBUG1) { #to delete CONTEXT lines
+        $dfile2 = $TMP2;
+        mysystem("grep -v '^CONTEXT:' '$TMP' | grep -v '^PL/pgSQL function' > $dfile2");
+        $dfile = $TMP3;
+        mysystem("grep -v '^CONTEXT:' '$dir/$x.result' | grep -v '^PL/pgSQL function' > $dfile");
+    }
+    else {
+        $dfile = "$dir/$x.result";
+        $dfile2 = $TMP;
+    }
+    if (! -f "$dir/$x.result") {
+        $res->{"$dir/$x.test.sql"} = "\nFAILED: result file missing : $!";
+        $stats{z_fail}++;            
+        next;
+    }
+
+    # use diff -w to ignore white space differences like \r vs \r\n
+    #ignore white spaces when comparing
+    #dfile is expected results
+    #dfile2 is the actual results
+    my $r = `diff -w '$dfile' '$dfile2' `;
+    #looks for removing leading blanks and trailing blanks
+    $r =~ s/^\s*|\s*$//g;
+    if ($r =~ /connection to server was lost/) {
+        $res->{"$dir/$x.test.sql"} = "CRASHED SERVER: $r";
+        $stats{z_crash}++;
+        # allow the server some time to recover from the crash
+        warn "CRASHED SERVER: '$dir/$x.test.sql', sleeping 5 ...\n";
+        sleep 20;
+    }
+    #if the diff has 0 length then everything was the same, so here we detect changes
+    elsif (length($r)) {
+        $res->{"$dir/$x.test.sql"} = "FAILED: $r";
+        $stats{z_fail}++ unless $DEBUG1;
+    }
+    else {
+        $res->{"$dir/$x.test.sql"} = "Passed";
+        $stats{z_pass}++;
+    }
+    print "    test run time: " . tv_interval($t0, [gettimeofday]) . "\n";
 }
 
 sub createTestDB {
@@ -359,10 +374,10 @@ sub createTestDB {
 
     # first create a database with postgis installed in it
     if (version_greater_eq($dbver, '9.1') &&
-            -f "$dbshare/extension/postgis.control") {
+        -f "$dbshare/extension/postgis.control") {
         mysystem("createdb $connopts $databaseName");
         die "ERROR: Failed to create database '$databaseName'!\n"
-            unless dbExists($databaseName);
+        unless dbExists($databaseName);
         my $encoding = '';
         if ($OS =~ /msys/
             || $OS =~ /MSWin/) {
@@ -400,7 +415,7 @@ sub createTestDB {
         -f "$dbshare/extension/postgis.control") {
         my $myver = '';
         if ($vpgr) {
-            $myver = " PGROUTING VERSION '$vpgr'";
+            $myver = " VERSION '$vpgr'";
         }
         print "-- Trying to install pgrouting extension $myver\n" if $DEBUG;
         mysystem("$psql $connopts -c \"create extension pgrouting $myver\" $databaseName");
